@@ -1,6 +1,6 @@
 #
 # Scan.pm
-# Last Modification: Thu Feb 14 13:26:10 WET 2002
+# Last Modification: Fri Feb 15 10:25:22 WET 2002
 #
 # Copyright (c) 2002 Henrique Dias <hdias@esb.ucp.pt>. All rights reserved.
 # This module is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@ use SelfLoader;
 use vars qw($VERSION @ISA @EXPORT $ERROR $virustxt %keywords);
 
 @ISA = qw(Exporter);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 $ERROR = "";
 
@@ -88,7 +88,7 @@ sub error {
 1;
 
 __DATA__
-# last change: 2002/02/14 13:55:43
+# last change: 2002/02/15 13:46:03
 sub load_txt_signs() {
 	$virustxt = {
 		"VBS/Carnival.gen\@MM" => ["Prinz_Charles_Are_Die.TXT.vbs","Prinz_Charles_Are_Die","Lucky2000.ico","CLICK","BLUE","BOTTLE","ICON","DESKTOP","YOUR","HARD","DRIVE","WILL","LOST","VIRUS","DAMAGE","COMPUTER","Prinz","Charles","Cool","Lucky2000","COOL_NOTEPAD_DEMO.TXT.vbs"],
@@ -106,7 +106,7 @@ sub load_txt_signs() {
 sub scan_text {
 	my$file = shift;
 
-	my $pattern = '([\w-\.]{2,})';
+	my $pattern = '([\w-\.]{2,29})';
 	my %hash = ();
 	local $/ = " ";
 	open(FILE, "<$file") or return(&set_error("$!"));
@@ -117,6 +117,7 @@ sub scan_text {
 		}
 	}
 	close(FILE);
+	return() if(scalar(keys(%hash)) < 16);
 	VIRUS: for my $name (%{$virustxt}) {
 		my $found = "";
 		for my $sign (@{$virustxt->{$name}}) {
@@ -203,7 +204,7 @@ File::Scan - Perl extension for Scanning files for Viruses
 =head1 DESCRIPTION
 
 This module is designed to allows users to scan files for known viruses.
-The purpose is to provide a perl module to make plattaform independent
+The purpose is to provide a perl module to make plataform independent
 virus scanners.
 
 =head1 METHODS
